@@ -1,55 +1,51 @@
 # ----------------------------------------------------------------------------------------------
-#' Aesthetics for biplot samples
+#' Format aesthetics for the biplot samples
 #'
 #' @description
-#' This function allows formatting changes to samples.
+#' This function allows the user to format the aesthetics for the samples.
 #'
 #' @param bp an object of class \code{biplot}.
-#' @param which vector of which groups of samples to display, with default \code{bp$g}.
-#' @param col sample colour, with default \code{blue}.
-#' @param pch sample plotting character, with default \code{+}.
-#' @param cex sample character expansion, with default \code{1}.
-#' @param label logical (\code{TRUE}, \code{FALSE}), whether samples should be labelled, with default \code{FALSE}. Alternatively, specify \code{"ggrepel"} for non-overlapping placement of labels.
-#' @param label.name vector of length number of samples, with default 
-#'\code{NULL}, \code{rownames(bp)} are used.
-#' @param label.col vector of length number of samples with the colour of the labels, defaulting to the
-#'                  colour of the sample points.
-#' @param label.cex label text expansion, with default \code{0.75}.
-#' @param label.side side of the plotting character where label appears, with default \code{bottom}. Note that unlike
-#'                   the argument `pos` in `text()`, options are "bottom", "left", "top", "right" and not 1, 2, 3, 4.
-#' @param label.offset offset of the label from the data point. See ?text for a detailed explanation of the
-#'                     argument `offset`.
-#' @param connected logical, whether samples are connected in order of rows of data matrix, with default \code{FALSE}.
-#' @param connect.col colour of the connecting line, with default \code{black}.
-#' @param connect.lty line type of the connecting line, with default \code{1}.
-#' @param connect.lwd line width of the connecting line, with default \code{1}.
-#' @param opacity opacity of sample points, with default 1 (opaque).
+#' @param which a vector containing the groups or classes for which the samples should be displayed, with default \code{bp$g}.
+#' @param col the colour(s) for the samples, with default \code{blue}.
+#' @param pch the plotting character(s) for the samples, with default \code{16}.
+#' @param cex the character expansion(s) for the samples, with default \code{1}.
+#' @param label a logical value indicating whether the samples should be labelled, with default \code{FALSE}. Alternatively, specify \code{"ggrepel"} for non-overlapping placement of labels.
+#' @param label.name a vector of the same length as \code{which} with label names for the samples, with default \code{NULL}. If \code{NULL}, the \code{rownames(bp)} are used. Alternatively, a custom vector of length \code{n} should be used.
+#' @param label.col a vector of the same length as \code{which} with label colours for the samples, with default as the same colour of the sample points.
+#' @param label.cex a vector of the same length as \code{which} with label text expansions for the samples, with default \code{0.75}.
+#' @param label.side the side at which the label of the plotted point appears, with default \code{bottom}. Note that unlike the argument \code{pos} in \code{text()}, options are "\code{bottom}", "\code{left}", "\code{top}", "\code{right}" and not \code{1}, \code{2}, \code{3}, \code{4}.
+#' @param label.offset the offset of the label from the plotted point. See \code{?text} for a detailed explanation of the argument \code{offset}.
+#' @param connected a logical value indicating whether samples are connected in order of rows of the data matrix, with default \code{FALSE}.
+#' @param connect.col the colour of the connecting line, with default \code{black}.
+#' @param connect.lty the line type of the connecting line, with default \code{1}.
+#' @param connect.lwd the line width of the connecting line, with default \code{1}.
+#' @param opacity the opacity level of the plotted points, with default \code{1} for an opaque point.
 #'
 #' @details
-#' The arguments `which`, `col`, `pch` and `cex` are based on the specification of `group.aes` or `classes`. If no groups
-#' are specified, a single colour, plotting character and / or character expansion is expected. If g groups are
-#' specified, vectors of length g is expected, or values are recycled to length g.
+#' The arguments \code{which}, \code{col}, \code{pch} and \code{cex} are based on the specification of \code{group.aes} or \code{classes}. If no groups are specified, a single colour, plotting character and / or character expansion is expected. If \eqn{g} groups are
+#' specified, vectors of length \eqn{g} is expected, or values are recycled to length \eqn{g}.
+#' 
+#' The arguments \code{label}, \code{label.cex}, \code{label.side} and \code{label.offset} are based on the sample size \eqn{n}. A single value
+#' will be recycled \eqn{n} times or a vector of length \eqn{n} is expected.
 #'
-#' The arguments `label`, `label.cex`, `label.side` and `label.offset` are based on the sample size n. A single value
-#' will be recycled n times or a vector of length n is expected.
+#' @return The object of class \code{biplot} will be appended with a list called \code{samples} containing the following elements:
+#' \item{which}{a vector containing the groups or classes for which the samples (and means) are displayed.}
+#' \item{col}{the colour(s) of the samples.}
+#' \item{pch}{the plotting character(s) of the samples.}
+#' \item{cex}{the character expansion(s) of the plotting character(s) of the samples.}
+#' \item{label}{a logical value indicating whether samples are labelled.}
+#' \item{label.name}{the label names of the samples.}
+#' \item{label.col}{the label colours of the samples.}
+#' \item{label.cex}{the label text expansions of the samples.}
+#' \item{label.side}{the side at which the label of the plotted point appears..}
+#' \item{label.offset}{the offset of the label from the plotted point.}
+#' \item{connected}{a logical value indicating whether samples are connected in order of the rows of the data matrix.}
+#' \item{connect.col}{the colour of the connecting line.}
+#' \item{connect.lty}{the line type of the connecting line.}
+#' \item{connect.lwd}{the line width of the connecting line.}
+#' \item{opacity}{the opacity level of the plotted points.}
 #'
-#' @return A list with the following components is available:
-#' \item{which}{which means to display.}
-#' \item{col}{colour of the samples.}
-#' \item{pch}{plotting character of the samples.}
-#' \item{cex}{expansion of the plotting character of the samples.}
-#' \item{label}{TRUE or FALSE, whether samples should be labelled, with default 
-#' \code{FALSE}.}
-#' \item{label.name}{If \code{NULL}, the row names will be used, with default \code{NULL}. Alternatively, a vector of length \code{n} should be used.}
-#' \item{label.col}{colour of the label.}
-#' \item{label.cex}{expansion of the label.}
-#' \item{label.side}{side at which to plot the label of samples.}
-#' \item{label.offset}{offset of the label from the data point.}
-#' \item{connected}{TRUE or FALSE, whether samples should be connected in row order of X.}
-#' \item{connect.col}{colour of the connecting line.}
-#' \item{connect.lty}{line type of the connecting line.}
-#' \item{connect.lwd}{line width of the connecting line.}
-#' \item{opacity}{opacity of sample points, with default 1 (opaque).}
+#' @seealso [biplot()]
 #'
 #' @usage
 #' samples (bp,  which = 1:bp$g, col = ez.col, pch = 16, cex = 1,
@@ -192,43 +188,42 @@ samples <- function (bp,  which = 1:bp$g, col = ez.col, pch = 16,
 }
 
 # ----------------------------------------------------------------------------------------------
-#' Aesthetics for biplot class / group means
+#' Format aesthetics for the class or group means
 #'
 #' @description
-#' This function allows formatting changes to class means or group means.
+#' This function allows the user to format the aesthetics for the class means or group means.
 #'
 #' @param bp an object of class \code{biplot}.
-#' @param which vector of which means to display, with default \code{bp$g}.
-#' @param col mean colour, with default to sample colour.
-#' @param pch mean plotting character, with default \code{o}.
-#' @param cex mean character expansion, with default \code{1}.
-#' @param label logical, whether means should be labelled or not, with default \code{TRUE}.
-#' @param label.col vector of length g with the colour of the labels, defaulting to the
-#'                  colour of the means.
-#' @param label.cex label text expansion, with default \code{0.75}.
-#' @param label.side side of the plotting character where label appears, with default \code{bottom}. Note that unlike
-#'                   the argument `pos` in `text()`, options are "bottom", "left", "top", "right" and not 1, 2, 3, 4.
-#' @param label.offset offset of the label from the mean point. See ?text for a detailed explanation of the
-#'                     argument `offset`.
+#' @param which a vector containing the groups or classes for which the means should be displayed, with default \code{bp$g}.
+#' @param col the colour(s) for the means, with default as the colour of the samples.
+#' @param pch the plotting character(s) for the means, with default \code{15}.
+#' @param cex the character expansion(s) for the means, with default \code{1}.
+#' @param label a logical value indicating whether the means should be labelled, with default \code{TRUE}.
+#' @param label.col a vector of the same length as \code{which} with label colours for the means, with default as the colour of the means.
+#' @param label.cex a vector of the same length as \code{which} with label text expansions for the means, with default \code{0.75}.
+#' @param label.side the side at which the label of the plotted mean point appears, with default \code{bottom}. Note that unlike the argument \code{pos} in \code{text()}, options are "\code{bottom}", "\code{left}", "\code{top}", "\code{right}" and not \code{1}, \code{2}, \code{3}, \code{4}.
+#' @param label.offset the offset of the label from the plotted mean point. See \code{?text} for a detailed explanation of the argument \code{offset}.
 #' @param opacity transparency of means.
-#' @param shade.darker automatically makes the colour of the means a darker shade than the default (or specified) colour
+#' @param shade.darker a logical value indicating whether the colour of the mean points should be made a shade darker than the default or specified colour, with default \code{TRUE}.
 #' 
 #' @details
 #' The number of classes or groups (defined by group.aes) is indicated as \code{g}. If an argument is not of length \code{g},
 #' recycling is used.
 #'
-#' @return A list with the following components is available:
-#' \item{which}{which means to display.}
-#' \item{col}{colour of the means.}
-#' \item{pch}{plotting character of the means.}
-#' \item{cex}{expansion of the plotting character of the means.}
-#' \item{label}{logical, whether means should be labelled.}
-#' \item{label.col}{colour of the label.}
-#' \item{label.cex}{expansion of the label.}
-#' \item{label.side}{side at which to plot the label of means.}
-#' \item{label.offset}{offset of the label from the mean point.}
-#' \item{opacity}{transparency of means}
+#' @return The object of class \code{biplot} will be appended with a list called \code{means} containing the following elements:
+#' \item{which}{a vector containing the groups or classes for which the means are displayed.}
+#' \item{col}{the colour(s) of the means.}
+#' \item{pch}{the plotting character(s) of the means.}
+#' \item{cex}{the character expansion(s) of the plotting character(s) of the means.}
+#' \item{label}{a logical value indicating whether means are labelled.}
+#' \item{label.col}{the label colours of the means.}
+#' \item{label.cex}{the label text expansions of the samples.}
+#' \item{label.side}{the side at which the label of the plotted mean point appears.}
+#' \item{label.offset}{the offset of the label from the plotted mean point.}
+#' \item{opacity}{the opacity level of the plotted points.}
 #'
+#' @seealso [biplot()]
+#' 
 #' @usage
 #' means (bp,  which = NULL, col = NULL, pch = 15, cex = 1, label = FALSE,
 #' label.col = NULL,label.cex = 0.75, label.side = "bottom", label.offset = 0.5,
@@ -243,6 +238,7 @@ means <- function (bp,  which = NULL, col = NULL,
                      pch = 15, cex = 1, label = FALSE, label.col=NULL, label.cex = 0.75,
                      label.side = "bottom", label.offset = 0.5, opacity = 1, shade.darker = TRUE)
 {
+  bp$show.class.means <- TRUE
   if (is.null(bp$samples)) bp <- samples(bp)
   g <- bp$g
   
@@ -308,72 +304,64 @@ means <- function (bp,  which = NULL, col = NULL,
 }
 
 # ----------------------------------------------------------------------------------------------
-#' Aesthetics for biplot axes
+#' Format aesthetics for the biplot axes
 #'
 #' @description
-#' This function allows formatting changes to axes.
+#' This function allows the user to format the aesthetics for the biplot axes.
 #'
 #'
 #' @param bp an object of class \code{biplot}.
-#' @param X.names refers to the column names of \code{bp} to specify which axes to label.
-#' @param which  integer-valued vector specifying which biplot axes are shown
-#' in a biplot. By default all p biplot axes are shown.
-#' @param col vector of size p specifying colours of labels of biplot axes. The default is \code{grey(0.7)}.
-#' @param lwd axis line width, with default \code{1}.
-#' @param lty axis line type, with default \code{1}.
-#' @param label.dir One of "Orthog" (default), "Hor" or "Paral" specifying titles of
-#' axes to appear orthogonal to the side of the figure; always
-#' horizontally or always parallel to the side of the figure.
-#' @param label.col axis label colour, with default, \code{col}.
-#' @param label.cex axis label expansion, with default \code{0.75}.
-#' @param label.line axis label written on which margin line, with default \code{0.1}.
-#' @param label.offset A four-component numeric vector controlling the distance a
-#' biplot axis title is printed from the side of the figure. Sides are
-#' numbered 1 to 4 according to R conventions clockwise starting
-#' from the bottom horizontal side. Default is rep(0,4)
-#' @param ticks integer-valued vector of size equal to the number of biplot axes
-#' to control the number of tickmarks on each individual biplot
-#' axis. Default is 5 for each axis.
-#' @param tick.col tick mark colour, with default \code{col}.
-#' @param tick.size positive integer-valued vector with specifying tick mark sizes, with default \code{1}.
-#' @param tick.label logical, whether axes should be labelled or not, with default \code{TRUE}.
-#' @param tick.label.side character vector specifying position of the tick label "below" or "above" the axis.
-#' @param tick.label.col tick mark label colour, with default \code{tick.col}.
-#' @param tick.label.cex tick mark label expansion, with default \code{0.6}.
-#' @param predict.col predicted samples colour, with default \code{col}.
-#' @param predict.lwd predicted samples line width, with default \code{lwd}.
-#' @param predict.lty predicted samples line type, with default \code{lty}.
-#' @param ax.names vector of size \code{p} containing user defined names for the variables.
-#' @param orthogx numeric vector of size p specifying the x-coordinate of the parallel transformation of each axis.
-#' Defaults to zero for each axis. Only used when the dimension of the biplot is two. 
-#' @param orthogy numeric vector of size p specifying the y-coordinate of the parallel transformation of each axis.
-#' Defaults to zero for each axis. Only used when the dimension of the biplot is two.
-#' @param vectors logical, whether calibrated axes should be displayed on the biplot
-#' @param unit.circle logical, whether a unit circle should be displayed on the biplot
+#' @param X.names a vector of column names of \code{bp} to specify which axes should be labelled.
+#' @param which a vector containing the columns or variables for which the axes should be displayed, with default \code{1:p}.
+#' @param col the colour(s) for the axes, with default \code{grey(0.7)}. Alternatively, provide a vector of colours corresponding to \code{X.names}.
+#' @param lwd the line width(s) for the axes, with default \code{1}.
+#' @param lty the line type(s) for the axes, with default \code{1}.
+#' @param label.dir a character string indicating the placement of the axis titles to the side of the figure. One of "\code{Orthog}" for axis titles to appear orthogonal to the side of the figure (default) , "\code{Hor}" for axis titles to appear horizontally or "\code{Paral}" for axis titles to appear parallel to the side of the figure.
+#' @param label.col the colour(s) for the axis labels, with default, \code{col}.
+#' @param label.cex the label expansion for the axis labels, with default \code{0.75}.
+#' @param label.line the distance of the axis title from the side of the figure, with default \code{0.1}.
+#' @param label.offset a four-component numeric vector controlling the distances axis titles are displayed from the side of the figure, with default \code{rep(0,4)}. Sides are numbered \code{1} to \code{4} according to \code{R} conventions.
+#' @param ticks an integer-valued vector indicating the number of tickmarks for each axis, with default \code{5} for each axis.
+#' @param tick.col the colour(s) for the tick marks, with default \code{col}.
+#' @param tick.size a vector specifying the sizes of tick marks for each axis, with default \code{1} for each .
+#' @param tick.label a logical value indicating whether the axes should be labelled, with default \code{TRUE}.
+#' @param tick.label.side a character string indicating the position of the tick label. One of "\code{below}" for the label to appear below the tick mark (default) or "\code{above}" for the label to appear above the tick mark.
+#' @param tick.label.col the colour(s) for the tick mark labels, with default \code{tick.col}.
+#' @param tick.label.cex the label expansion for the tick mark labels, with default \code{0.6}.
+#' @param predict.col the colour(s) for the predicted samples, with default \code{col}.
+#' @param predict.lwd the line width(s) for the predicted samples, with default \code{lwd}.
+#' @param predict.lty the line type(s) for the predicted samples, with default \code{lty}.
+#' @param ax.names a vector of size \code{p} containing user defined titles for the axes.
+#' @param orthogx a numeric vector of size \code{p} specifying the x-coordinate of the parallel transformation of each axis, with default \code{0} for each axis. This is only used when \code{dim.biplot = 2}. 
+#' @param orthogy a numeric vector of size \code{p} specifying the y-coordinate of the parallel transformation of each axis, with default \code{0} for each axis. This is only used when \code{dim.biplot = 2}.
+#' @param vectors a logical value indicating whether vector representation (calibrated axes) should be displayed on the biplot. This is only used when a PCA biplot is produced.
+#' @param unit.circle a logical value indicating whether a unit circle should be displayed on the biplot.
 #'
-#' @return A list with the following components is available:
-#' \item{which}{vector of the columns displayed as axes.}
-#' \item{col}{vector of axis colours.}
-#' \item{lwd}{vector of axis line widths.}
-#' \item{lty}{vector of axis line types.}
-#' \item{label.dir}{direction of the axis labels.}
-#' \item{label.col}{vector of axis label colours.}
-#' \item{label.cex}{vector of axis labels expansions.}
-#' \item{label.line}{vector of axis label margin lines from axes.}
-#' \item{ticks}{vector representing the number of tick marks per axis.}
-#' \item{tick.col}{vector of tick mark colours.}
-#' \item{tick.size}{vector of tick mark sizes.}
-#' \item{tick.label}{vector of logical values indicating whether axes are labelled.}
-#' \item{tick.label.side}{vector specifying position of the tick label "below" or "above" the axis.}
-#' \item{tick.label.col}{vector of tick mark label colours.}
-#' \item{tick.label.cex}{vector of tick mark label expansions.}
-#' \item{predict.col}{vector of colours for the predicted samples.}
-#' \item{predict.lty}{vector of line types for the predicted samples.}
-#' \item{predict.lwd}{vector of line widths for the predicted samples.}
-#' \item{names}{vector of variable names defined by the user.}
-#' \item{orthogx}{vector of the horisontal translations for each axis.}
-#' \item{orthogy}{vector of the vertical translations for each axis.}
-#' \item{calibrated.axis}{whether to plot calibrated axis}
+#' @return The object of class \code{biplot} will be appended with a list called \code{axes} containing the following elements:
+#' \item{which}{a vector containing the columns for which the axes are displayed.}
+#' \item{col}{the colour(s) of the axes.}
+#' \item{lwd}{the line width(s) of the axes.}
+#' \item{lty}{the line type(s) of the axes.}
+#' \item{label.dir}{the placement of the axis titles to the side of the figure.}
+#' \item{label.col}{the colour(s) of the axis titles.}
+#' \item{label.cex}{the label expansion(s) of the axis titles.}
+#' \item{label.line}{the distance(s) of the axis titles from the side of the figure.}
+#' \item{ticks}{the number of tick marks per axis.}
+#' \item{tick.col}{the colour(s) of the tick marks.}
+#' \item{tick.size}{the size(s) of the tick marks.}
+#' \item{tick.label}{logical value(s) indicating whether axes are labelled.}
+#' \item{tick.label.side}{the position of the tick mark labels.}
+#' \item{tick.label.col}{the colour(s) of the tick mark labels.}
+#' \item{tick.label.cex}{the expansion(s) of the tick mark labels.}
+#' \item{predict.col}{the colour(s) of the predicted samples.}
+#' \item{predict.lty}{the line type(s) of the predicted samples.}
+#' \item{predict.lwd}{the line width(s) of the predicted samples.}
+#' \item{names}{the user defined axis titles.}
+#' \item{orthogx}{the horizontal translations for each axis.}
+#' \item{orthogy}{the vertical translations for each axis.}
+#' \item{vectors}{a logical value indicating whether calibrated axes are plotted.}
+#' 
+#' @seealso [biplot()]
 #'
 #' @usage
 #' axes(bp, X.names=colnames(bp$X), which = 1:bp$p, col = grey(0.7), lwd = 1, lty = 1,
@@ -515,37 +503,35 @@ axes <- function (bp, X.names=colnames(bp$X), which = 1:bp$p, col = grey(0.7), l
 #'
 control.alpha.bags <- function (g, g.names, alpha, which=NULL, col, lty, lwd, max, opacity)
 {
-  if (!all(is.numeric(which)))
-    which <- match(which, g.names, nomatch = 0)
+  if (!all(is.numeric(which))) which <- match(which, g.names, nomatch = 0)
   which <- which[which <= g]
   which <- which[which > 0]
 
-  if ((length(alpha) > 1) & (length(alpha) != length(which))){
+  ww <- length(which)
+  if ((length(alpha) > 1) & (length(alpha) != length(which)))
+  {
     temp.mat <- expand.grid(which, alpha)
     which <- temp.mat[,1]
     alpha <- temp.mat[,2]
   }
-  ww <- length(which)
-
   bag.num <- length(which)
-  while (length(alpha) < bag.num)
-    alpha <- c(alpha, alpha)
-  alpha <- as.vector(alpha[1:bag.num])
+
+  while (length(alpha) < bag.num) alpha <- c(alpha, alpha)
+  alpha <- alpha[1:bag.num]
   if (any(alpha < 0 | alpha > 0.99))
     stop(message = "alpha not to be negative or larger than 0.99")
 
-  
   if (is.null(col)) col <- ez.col[which]
-  while (length(col) < bag.num)
-    col <- c(col, col)
+  col <- stats::na.omit(col)
+  while (length(col) < bag.num) col <- c(col, col)
   col <- col[1:bag.num]
-  while (length(lty) < bag.num)
-    lty <- rep(lty, each=ww)
+  while (length(lty) < bag.num) lty <- rep(lty, each=ww)
   lty <- lty[1:bag.num]
-  while (length(lwd) < bag.num)
-    lwd <- rep(lwd, each=ww)
+  while (length(lwd) < bag.num) lwd <- rep(lwd, each=ww)
   lwd <- lwd[1:bag.num]
   while (length(opacity) < bag.num) opacity <- c(opacity, opacity)
+  opacity <- opacity[1:bag.num]
+  
   list(which = which, alpha = alpha, col = col, lty = lty, lwd = lwd, max = max, opacity = opacity)
 }
 
@@ -572,21 +558,20 @@ control.concentration.ellipse <- function (g, g.names, df, kappa, which,
   if (!all(is.numeric(which))) which <- match(which, g.names, nomatch = 0)
   which <- which[which <= g]
   which <- which[which > 0]
-  ww <- length(which)
 
+  ww <- length(which)
   if ((length(kappa) > 1) & (length(kappa) != length(which)))
   {
     temp.mat <- expand.grid(which, kappa)
     which <- temp.mat[,1]
     kappa <- temp.mat[,2]
   }
-  ww <- length(which)
-  
   ellipse.num <- length(which)
+  
   while (length(kappa) < ellipse.num) kappa <- c(kappa, kappa)
-  kappa <- as.vector(kappa[1:ellipse.num])
-
+  kappa <- kappa[1:ellipse.num]
   if (is.null(col)) col <- ez.col[which]
+  col <- stats::na.omit(col)
   while (length(col) < ellipse.num) col <- c(col, col)
   col <- col[1:ellipse.num]
   while (length(lty) < ellipse.num) lty <- rep(lty, each=ww)
@@ -594,47 +579,118 @@ control.concentration.ellipse <- function (g, g.names, df, kappa, which,
   while (length(lwd) < ellipse.num) lwd <- rep(lwd, each=ww)
   lwd <- as.vector(lwd[1:ellipse.num])
   while (length(opacity) < ellipse.num) opacity <- c(opacity, opacity)
+  opacity <- opacity[1:ellipse.num]
 
   list(which = which, kappa = kappa, col = col, lty = lty, lwd = lwd, opacity = opacity)
 }
 
 # ----------------------------------------------------------------------------------------------
-#' Aesthetics for supplementary (new) biplot samples
+#' Format aesthetics for the category level points
+#'
+#' @description
+#' This function allows the user to format the aesthetics for the category level points (CLPs).
+#'
+#' @param bp an object of class \code{biplot}.
+#' @param which a vector containing the columns or variables for which the CLPs should be displayed, with default \code{ncol(Xcat)}.
+#' @param col the colour(s) for the CLPs, with default \code{black}.
+#' @param cex the character expansion(s) for the CLPs, with default \code{0.6}.
+#'
+#' @return The object of class \code{biplot} will be appended with a list called \code{CLP.aes} containing the following elements  A list with the following components is available:
+#' \item{which}{a vector containing the columns or variables for which the CLPs are displayed.}
+#' \item{col}{the colour(s) of the CLPs.}
+#' \item{cex}{the character expansion(s) of the plotting characters of the CLPs.}
+#'
+#' @seealso \code{\link{biplot}}, \code{\link{CA}}, \code{\link{AoD}}
+#' 
+#' @usage
+#' CLPs (bp,  which = 1:ncol(bp$Xcat), col = "black", cex = 0.6)
+#' @aliases CLPs
+#'
+#' @export
+#'
+#' @examples 
+#' mtdf <- as.data.frame(mtcars)
+#' mtdf$cyl <- factor(mtdf$cyl)
+#' mtdf$vs <- factor(mtdf$vs)
+#' mtdf$am <- factor(mtdf$am)
+#' mtdf$gear <- factor(mtdf$gear)
+#' mtdf$carb <- factor(mtdf$carb)
+#' biplot(mtdf[,-11], scaled = TRUE) |> AoD(classes = mtdf[,11]) |> 
+#' CLPs(col = list(rep("olivedrab",3), rep("orange",2),
+#'                 rep("coral",2), rep("brown",3))) |> 
+#' plot()
+#' 
+CLPs <- function (bp,  which = 1:ncol(bp$Xcat), col = "black", cex = 0.6)
+{
+  p2 <- ncol(bp$Xcat)
+  if(is.null(which) & length(col)==0) col <- ez.col
+  
+  if (!is.null(which))
+  {
+    if (!all(is.numeric(which))) which <- match(which, bp$colnames(bp$Xcat), nomatch = 0)
+    which <- which[which <= p2]
+    which <- which[which > 0]
+  }
+
+  # Expand col to length p2
+  if (!is.list(col)) col <- list(col)
+  while (length(col) < length(which)) col[[length(col)+1]] <- col[[1]]
+  for (j in 1:length(col))
+  {
+    col.len <- length(col[[j]])
+    num.lev <- nlevels(bp$Xcat[,j])
+    col[[j]] <- col[[j]][ifelse(1:num.lev%%col.len==0, col.len, 1:num.lev%%col.len)]
+  }
+
+  # Expand cex to length p2
+  if (!is.list(cex)) cex <- list(cex)
+  while (length(cex) < length(which)) cex[[length(cex)+1]] <- cex[[1]]
+  for (j in 1:length(cex))
+  {
+    cex.len <- length(cex[[j]])
+    num.lev <- nlevels(bp$Xcat[,j])
+    cex[[j]] <- cex[[j]][ifelse(1:num.lev%%cex.len==0, cex.len, 1:num.lev%%cex.len)]
+  }
+
+  bp$CLP.aes = list(which = which, col = col, cex = cex)
+  bp
+}
+# ----------------------------------------------------------------------------------------------
+#' Format aesthetics for the supplementary (new) biplot samples
 #'
 #' @description
 #' This function allows formatting changes to new samples.
 #'
 #' @param bp an object of class \code{biplot}.
-#' @param col new sample colour, with default \code{darkorange1}.
-#' @param pch new sample plotting character, with default \code{o}.
-#' @param cex new sample character expansion, with default \code{1}.
-#' @param label logical, whether samples should be labelled or not, with default \code{FALSE}.
-#' @param label.name names for the new samples
-#' @param label.col vector of length number of new samples with the colour of the labels, defaulting to the
-#'                  colour of the sample points.
-#' @param label.cex label text expansion, with default \code{0.75}.
-#' @param label.side side of the plotting character where label appears, with default \code{bottom}. Note that unlike
-#'                   the argument `pos` in `text()`, options are "bottom", "left", "top", "right" and not 1, 2, 3, 4.
-#' @param label.offset offset of the label from the data point. See ?text for a detailed explanation of the
-#'                     argument `offset`.
-#' @param connected logical, whether samples are connected in order of rows of data matrix, with default \code{FALSE}.
-#' @param connect.col colour of the connecting line, with default \code{black}.
-#' @param connect.lty line type of the connecting line, with default \code{1}.
-#' @param connect.lwd line width of the connecting line, with default \code{1}.
+#' @param col the colour(s) for the new samples, with default \code{darkorange1}.
+#' @param pch the plotting character(s) for the new samples, with default \code{1}.
+#' @param cex the character expansion(s) for the new samples, with default \code{1}.
+#' @param label a logical value indicating whether new samples should be labelled or not, with default \code{FALSE}.
+#' @param label.name the label names for the new samples.
+#' @param label.col a vector of the same length as the number of new samples containing the colour(s) for the labels of the new samples, with default the colour of the sample points.
+#' @param label.cex the label text expansion(s) for the new samples, with default \code{0.75}.
+#' @param label.side the side at which the label of the plotted point appears, with default \code{bottom}. Note that unlike the argument \code{pos} in \code{text()}, options are "\code{bottom}", "\code{left}", "\code{top}","\code{right}" and not \code{1}, \code{2}, \code{3}, \code{4}.
+#' @param label.offset the offset of the label from the plotted point. See \code{?text} for a detailed explanation of the argument \code{offset}. 
+#' @param connected a logical value indicating whether samples are connected in order of rows of the data matrix, with default \code{FALSE}.
+#' @param connect.col the colour of the connecting line, with default \code{black}.
+#' @param connect.lty the line type of the connecting line, with default \code{1}.
+#' @param connect.lwd the line width of the connecting line, with default \code{1}.
 #'
-#' @return A list with the following components is available:
-#' \item{col}{colour of the samples.}
-#' \item{pch}{plotting character of the samples.}
-#' \item{cex}{expansion of the plotting character of the samples.}
-#' \item{label}{TRUE or FALSE, whether samples should be labelled.}
-#' \item{label.col}{colour of the label.}
-#' \item{label.cex}{expansion of the label.}
-#' \item{label.side}{side at which to plot the label of samples.}
-#' \item{label.offset}{offset of the label from the data point.}
-#' \item{connected}{TRUE or FALSE, whether samples should be connected in row order of X.}
-#' \item{connect.col}{colour of the connecting line.}
-#' \item{connect.lty}{line type of the connecting line.}
-#' \item{connect.lwd}{line width of the connecting line.}
+#' @return The object of class \code{biplot} will be appended with a list called \code{newsamples} containing the following elements:
+#' \item{col}{the colour(s) of the new samples.}
+#' \item{pch}{the plotting character(s) of the new samples.}
+#' \item{cex}{the character expansion(s) of the plotting character(s) of the new samples.}
+#' \item{label}{a logical value indicating whether new samples are labelled.}
+#' \item{label.col}{the label colours of the new samples.}
+#' \item{label.cex}{the label text expansions of the new samples.}
+#' \item{label.side}{the side at which the label of the plotted point appears.}
+#' \item{label.offset}{the offset of the label from the plotted point.}
+#' \item{connected}{a logical value indicating whether new samples are connected.}
+#' \item{connect.col}{the colour of the connecting line.}
+#' \item{connect.lty}{the line type of the connecting line.}
+#' \item{connect.lwd}{the line width of the connecting line.}
+#'
+#' @seealso \link{biplot}, \link{samples}
 #'
 #' @usage
 #' newsamples (bp,  col = "darkorange1", pch = 1, cex = 1, label = FALSE,
@@ -702,16 +758,21 @@ newsamples <- function (bp,  col = "darkorange1", pch = 1, cex = 1,
 }
 
 
-#' Aesthetics for supplementary (new) biplot axes
+#' Format aesthetics for the supplementary (new) biplot axes
+#' 
+#' @description 
+#' This function allows the user to format the aesthetics for the supplementary (new) biplot axes.
 #'
-#' @param bp object of class `biplot`
-#' @param X.new.names refers to the new column names of \code{bp} to specify which axes to label.
-#' @param which vector of new columns to be displayed in the biplot.
+#' @param bp an object of class \code{biplot}.
+#' @param X.new.names a vector of the new column names of \code{bp} to specify which axes should be labelled.
+#' @param which a vector containing the new columns or variables for which the axes should be displayed, with default \code{1:num.vars}.
 #' @inheritParams axes
 #'
-#' @return an object of class `biplot`
+#' @return The object of class \code{biplot} will be appended with a list called \code{newaxes} containing elements similar to that of \code{axes}.
 #' @export
 #'
+#' @seealso \code{\link{biplot}}, \code{\link{axes}}
+#'
 #' @usage
 #' newaxes(bp, X.new.names=bp$var.names, which = 1:bp$num.vars, col = "orange", lwd = 1, 
 #' lty = 1, label.dir = "Orthog", label.col = col, label.cex = 0.75, label.line = 0.1, 
